# Elastic App Search

Welcome to [Elastic App Search](https://www.elastic.co/solutions/app-search)!

App Search offers robust search APIs with unprecedented relevance controls -- all backed by the Elastic Stack.

## Support and Feedback

If you run into any issues or bugs, please [email the support team](mailto:support@elastic.co).

The [App Search community forum](https://discuss.elastic.co/c/app-search) is also a great place to share knowledge and receive advice.

Known issues and useful information will be kept up-to-date within the [App Search documentation](https://swiftype.com/documentation/app-search/self-managed/overview).

## Requirements

**Supported platforms:**

* Linux: x86_64 only
* MacOS X: High Sierra 10.13 - 10.1x (64 bit only)
* Windows: Not supported

View the [full support matrix](https://elastic.co/support/matrix) on Elastic.co.

**Minimum hardware:**

* ~4GB of free RAM or 6GB if Elasticsearch is running on the same machine.
  * 2GB for App Server.
  * 2GB for Worker.
  * 50Mb for [Filebeat](https://www.elastic.co/products/beats/filebeat) and other processes.
* 5GB of disk space available.

**Dependencies:**

* Install [Java 8](https://www.oracle.com/technetwork/java/javase/downloads/jdk8-downloads-2133151.html) or [Java 11](https://www.oracle.com/technetwork/java/javase/downloads/jdk11-downloads-5066655.html).
* Licensed [Elasticsearch](https://www.elastic.co/downloads/elasticsearch) 7.4.x.

**Elasticsearch License:**

* Elasticsearch must have at least a basic license.
  - A **free Basic license** is included when downloading Elasticsearch from [Elastic.co](https://www.elastic.co/downloads/elasticsearch).

## Running App Search

Ensure a compatible Elasticsearch cluster is running:

`bin/elasticsearch`

Run `curl http://localhost:9200/` to confirm you can reach Elasticsearch:

```json
{
  // ....
  },
  "tagline" : "You Know, for Search"
}
```

Next, configure how App Search will interact with Elasticsearch.

Choose **one** of the following options:

1. Allow App Search to modify cluster settings. Add the following line to App Search's `config/app-search.yml`: `allow_es_settings_modification: true`

2. Allow Elasticsearch to create indexes automatically. Add the following line to Elasticsearch's `elasticsearch.yml` or within your Elasticsearch cluster settings: `action.auto_create_index: ".app-search-*-logs-*,-.app-search-*,+*"`

After that, enter the App Search directory and run...

`bin/app-search`

Wait until App Search has started, then visit http://localhost:3002.

The default login credentials are:

* **Email**: app-search@example.com
* **Password**: Check your console output for the generated password.

Enjoy!

## Using the API

An example search query:

```bash
curl -X POST 'http://localhost:3002/api/as/v1/engines/[YOUR_ENGINE_NAME]/search' \
     -H 'Content-Type: application/json' \
     -H 'Authorization: Bearer [YOUR_SEARCH_KEY]' \
     -d '{ "query": "mountain" }'
```

Note that queries to a self-managed instance will be different than those in the documentation. Self-managed endpoints do not require a **Host Identifier**.

## Configuration & Troubleshooting

Refer to the [documentation](http://swiftype.com/documentation/app-search/self-managed/overview) for full assistance.
